@@ -17,7 +17,7 @@ class Result(result.Result):
         return self.analysis.tracer_for_instance(instance=instance)
 
     @property
-    def source_plane_light_profile_centres(self) -> grids.GridCoordinates:
+    def source_plane_light_profile_centres(self) -> grids.GridIrregularGrouped:
         """Return a list of all light profiles centres of all galaxies in the most-likely tracer's source-plane.
 
         These centres are used by automatic position updating to determine the best-fit lens model's image-plane
@@ -25,7 +25,7 @@ class Result(result.Result):
         return self.max_log_likelihood_tracer.source_plane.light_profile_centres
 
     @property
-    def source_plane_inversion_centres(self) -> grids.GridCoordinates:
+    def source_plane_inversion_centres(self) -> grids.GridIrregularGrouped:
         """Return a list of all centres of a pixelized source reconstruction in the source-plane of the most likely fit.
         The brightest source pixel(s) are used to determine these centres.
 
@@ -39,7 +39,7 @@ class Result(result.Result):
             return []
 
     @property
-    def source_plane_centres(self) -> grids.GridCoordinates:
+    def source_plane_centres(self) -> grids.GridIrregularGrouped:
         """Combine the source-plane light profile and inversion centres (see above) into a single list of source-plane
         centres.
 
@@ -50,12 +50,12 @@ class Result(result.Result):
             self.source_plane_inversion_centres
         )
 
-        return grids.GridCoordinates(coordinates=centres)
+        return grids.GridIrregularGrouped(grid=centres)
 
     @property
     def image_plane_multiple_image_positions_of_source_plane_centres(
-        self
-    ) -> grids.GridCoordinates:
+        self,
+    ) -> grids.GridIrregularGrouped:
         """Backwards ray-trace the source-plane centres (see above) to the image-plane via the mass model, to determine
         the multiple image position of the source(s) in the image-plane..
 
@@ -74,9 +74,9 @@ class Result(result.Result):
                     lensing_obj=self.max_log_likelihood_tracer,
                     source_plane_coordinate=centre,
                 )
-                for centre in self.source_plane_centres.in_list[0]
+                for centre in self.source_plane_centres.in_grouped_list[0]
             ]
-            return grids.GridCoordinates(coordinates=multiple_images)
+            return grids.GridIrregularGrouped(grid=multiple_images)
         except IndexError:
             return None
 
