@@ -1,6 +1,5 @@
-import autofit as af
+from os import path
 import autolens as al
-import autolens.plot as aplt
 
 """
 This script simulates `Imaging` of a strong lens where:
@@ -19,6 +18,7 @@ gives it a descriptive name. They define the folder the dataset is output to on
  - The noise-map will be output to `/autolens_workspace/dataset/dataset_type/dataset_name/lens_name/noise_map.fits`.
  - The psf will be output to `/autolens_workspace/dataset/dataset_type/dataset_name/psf.fits`.
 """
+
 dataset_type = "chapter_3"
 dataset_name = "mass_sie__source_sersic_x4"
 
@@ -26,7 +26,8 @@ dataset_name = "mass_sie__source_sersic_x4"
 The path where the dataset will be output, which in this case is:
 `/autolens_workspace/howtolens/dataset/chapter_2/lens_sis__source_sersic_x5/`
 """
-dataset_path = f"dataset/howtolens/{dataset_type}/{dataset_name}"
+
+dataset_path = path.join("dataset", "howtolens", dataset_type, dataset_name)
 
 """
 For simulating an image of a strong lens, we recommend using a GridIterate object. This represents a grid of $(y,x)$ 
@@ -37,6 +38,7 @@ sub-size of the grid is iteratively increased (in steps of 2, 4, 8, 16, 24) unti
 This ensures that the divergent and bright central regions of the source galaxy are fully resolved when determining the
 total flux emitted within a pixel.
 """
+
 grid = al.GridIterate.uniform(
     shape_2d=(100, 100),
     pixel_scales=0.1,
@@ -45,6 +47,7 @@ grid = al.GridIterate.uniform(
 )
 
 """Simulate a simple Gaussian PSF for the image."""
+
 psf = al.Kernel.from_gaussian(
     shape_2d=(11, 11), sigma=0.1, pixel_scales=grid.pixel_scales
 )
@@ -53,6 +56,7 @@ psf = al.Kernel.from_gaussian(
 To simulate the `Imaging` dataset we first create a simulator, which defines the exposure time, background sky,
 noise levels and psf of the dataset that is simulated.
 """
+
 simulator = al.SimulatorImaging(
     exposure_time=300.0, psf=psf, background_sky_level=0.1, add_poisson_noise=True
 )
@@ -121,6 +125,7 @@ source_galaxy_3 = al.Galaxy(
 )
 
 """Use these galaxies to setup a tracer, which will generate the image for the simulated `Imaging` dataset."""
+
 tracer = al.Tracer.from_galaxies(
     galaxies=[
         lens_galaxy,
@@ -135,13 +140,15 @@ tracer = al.Tracer.from_galaxies(
 We can now pass this simulator a tracer, which creates the ray-traced image plotted above and simulates it as an
 imaging dataset.
 """
+
 imaging = simulator.from_tracer_and_grid(tracer=tracer, grid=grid)
 
 """Output our simulated dataset to the dataset path as .fits files"""
+
 imaging.output_to_fits(
-    image_path=f"{dataset_path}/image.fits",
-    psf_path=f"{dataset_path}/psf.fits",
-    noise_map_path=f"{dataset_path}/noise_map.fits",
+    image_path=path.join(dataset_path, "image.fits"),
+    psf_path=path.join(dataset_path, "psf.fits"),
+    noise_map_path=path.join(dataset_path, "noise_map.fits"),
     overwrite=True,
 )
 
@@ -151,4 +158,5 @@ check how the dataset was simulated in the future.
 
 This will also be accessible via the `Aggregator` if a model-fit is performed using the dataset.
 """
+
 tracer.save(file_path=dataset_path, filename="true_tracer")
